==> kidentitymanagement-22.04.3-x86_64-1.txz: usr/lib64/cmake/KF5IdentityManagement/KF5IdentityManagementTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF5::IdentityManagement" for configuration "Release"
set_property(TARGET KF5::IdentityManagement APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF5::IdentityManagement PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::CoreAddons;KF5::ConfigCore;KF5::Codecs;KF5::I18n;Qt5::DBus;Qt5::Network"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libKF5IdentityManagement.so.5.20.3"
  IMPORTED_SONAME_RELEASE "libKF5IdentityManagement.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::IdentityManagement )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::IdentityManagement "${_IMPORT_PREFIX}/lib64/libKF5IdentityManagement.so.5.20.3" )

# Import target "KF5::IdentityManagementWidgets" for configuration "Release"
set_property(TARGET KF5::IdentityManagementWidgets APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF5::IdentityManagementWidgets PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::CoreAddons;KF5::PimTextEdit;KF5::Codecs;Qt5::Network;KF5::I18n;KF5::WidgetsAddons;KF5::XmlGui;KF5::KIOWidgets;KF5::ConfigCore"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libKF5IdentityManagementWidgets.so.5.20.3"
  IMPORTED_SONAME_RELEASE "libKF5IdentityManagementWidgets.so.5"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::IdentityManagementWidgets )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::IdentityManagementWidgets "${_IMPORT_PREFIX}/lib64/libKF5IdentityManagementWidgets.so.5.20.3" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> kidentitymanagement-22.08.0-x86_64-1.txz: usr/lib64/cmake/KF5IdentityManagement/KF5IdentityManagementTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF5::IdentityManagement" for configuration "Release"
set_property(TARGET KF5::IdentityManagement APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF5::IdentityManagement PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::CoreAddons;KF5::ConfigCore;KF5::Codecs;KF5::I18n;Qt5::DBus;Qt5::Network"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libKF5IdentityManagement.so.5.21.0"
  IMPORTED_SONAME_RELEASE "libKF5IdentityManagement.so.5"
  )

list(APPEND _cmake_import_check_targets KF5::IdentityManagement )
list(APPEND _cmake_import_check_files_for_KF5::IdentityManagement "${_IMPORT_PREFIX}/lib64/libKF5IdentityManagement.so.5.21.0" )

# Import target "KF5::IdentityManagementWidgets" for configuration "Release"
set_property(TARGET KF5::IdentityManagementWidgets APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF5::IdentityManagementWidgets PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::CoreAddons;KF5::PimTextEdit;KF5::Codecs;Qt5::Network;KF5::I18n;KF5::WidgetsAddons;KF5::XmlGui;KF5::KIOWidgets;KF5::ConfigCore"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib64/libKF5IdentityManagementWidgets.so.5.21.0"
  IMPORTED_SONAME_RELEASE "libKF5IdentityManagementWidgets.so.5"
  )

list(APPEND _cmake_import_check_targets KF5::IdentityManagementWidgets )
list(APPEND _cmake_import_check_files_for_KF5::IdentityManagementWidgets "${_IMPORT_PREFIX}/lib64/libKF5IdentityManagementWidgets.so.5.21.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
